function result = dictLookup(nBy2CellArray, keys)
% result = dictLookup(nBy2CellArray, keys)
%
% This will assume that the values stored are in column form. 
%	Keys is an array of any type (you may have to create an array of length 1)
%	nBy2CellArray is a matrix of cells that are two columns and many rows.  
%		The first column are the keys and the second is the associated
%		value for that key.
%   This function may not give desired results if keys have corresponding
%   values that are of different types (e.g. one key corresponds to a col
%   of double and another a col of char)
%	
% A sample nBy2CellArray may look like:
%    'TrialNumber'       [44x1  double]
%    'Response'          [44x1  double]
%    's_dist'            [44x1  double]
%    't_a_dist'          [44x1  double]
%    'p_dist'            [44x1  double]
%    'Start_pt'          [44x37 char  ]
%    'Max_pt'            [44x37 char  ]
%    'App_pt'            [44x37 char  ]
%    'Coll_pt'           [44x37 char  ]
%    'Traj_length'       [44x1  double]
%    'betaOradC'         [44x1  double]
%    'Fade_type'         [44x1  char  ]
%    'vis_time'          [44x1  double]
%    'vis_dist'          [44x1  double]
%    'Walk_speed'        [44x1  double]
%    'Vanish_dist'       [44x1  double]
%    'Time_obs_vis'      [44x1  double]
%    'Dist_obs_vis'      [44x1  double]
%    'Obstacle'          [44x13 char  ]
%    'Obs_size'          [44x1  double]
%    'Obs_side'          [44x1  double]
%    'Fade_Time'         [44x1  double]
%    'average_p_dist'    [44x1  double]
%    'first_p_dist'      [44x1  double]
%    'last_p_dist'       [44x1  double]
%    'PracticeT'         [44x1  char  ]

result = [];



for i = 1:length(keys)
    [tf, index] = ismember(nBy2CellArray(:,1), keys(i));
    actualIndex = find(index);
    
    if ~isempty(actualIndex)
        % We found the value associated with the key
        result = [result nBy2CellArray{find(index),2}];
    else
        warning(['WARNING: Key ', char(keys(i)), ' not found.'])
    end
end
