function [] = plotFigureALLXERRORv2(allXErrorsTCS, allXErrorsTCSValid)
figure
stepSize = 1/2.54; % stepSize is in inches
binVector = [-25:stepSize:25];
[n, x] = hist(allXErrorsTCS,binVector);

hold on
yValues = (1/stepSize)*100*n / sum(n);
patch(x * 2.54, yValues,  [.65 .65 .65])

% Now create a patch for the data without area 'A'
[n2, x2] = hist(allXErrorsTCSValid,binVector);
yValues2 = (1/stepSize)*100*n2 / sum(n);
h = patch(x2 * 2.54, yValues2, 'k');
set(h,'FaceAlpha',.3);

% Add lines for boundaries  NOTE:  These change depending on whether
% the sensor was mounted on front or back.  Also, 2.54 is to convert to cm.
rearProjectionDistance = 26 * 2.54;
backSafetyDistance = -21 * 2.54;  % Should be negative

line([backSafetyDistance backSafetyDistance], [0 max(n)], 'Color', 'k','LineWidth',3)
line([rearProjectionDistance rearProjectionDistance], [0 max(n)], 'Color', 'k','LineWidth',3)
line([0 0], [0 max(yValues2)], 'Color', 'k','LineWidth',3)

% Make the x-axis match the walking figure from the methods section
set(gca,'XDir','reverse')

ylim([0 round(max(yValues)+2)])
xlim([-24 * 2.54  26.15 * 2.54])

% Annotate the 'A'
annotation('arrow', [.70 .69], [.24 .15]);


% Display percentages.
theXs = [x;x2];
theDatas = [{allXErrorsTCS} {allXErrorsTCSValid}];
yVals = [{yValues} {yValues2* sum(n)/sum(n2)}];
for i = 1:2
    disp(['Number of actual samples: ' num2str(length(theDatas{i}))])

    indices = find((2.54 * theXs(i,:)) >= -15 & (2.54 * theXs(i,:)) <= 15);
    disp(['Percentage between -15 and 15 cm : ' num2str(sum(yVals{i}(indices))*stepSize)])

    indices = find((2.54 * theXs(i,:)) > -53 & (2.54 * theXs(i,:)) < -15);
    disp(['Percentage between -53 and -15 cm: ' num2str(sum(yVals{i}(indices))*stepSize)])

    indices = find( (2.54 * theXs(i,:)) <= -53);
    disp(['Percentage less than -53 cm: ' num2str(sum(yVals{i}(indices))*stepSize)])

    indices = find((2.54 * theXs(i,:)) > 15 );
    disp(['Percentage greater than 15 cm:' num2str(sum(yVals{i}(indices))*stepSize)])

end

xlabel('x_{error} (cm)', 'FontSize', 36 )
ylabel('Percentage of All Samples', 'FontSize', 36)

text(-24.3, 3.482, 'A', 'FontSize', 56)
text(backSafetyDistance - .5, (1/stepSize)*.4, 'B', 'FontSize', 56)
text(-1, round(max(yValues)+1), 'x_0','FontSize', 48, 'HorizontalAlignment', 'Center')
text(backSafetyDistance + 1.5, 15.5, {'Back'; 'Safety';'Limit'},'FontSize', 30, 'HorizontalAlignment', 'Right')
text(rearProjectionDistance - 1.5, 15.5, {'Front';'Rail'},'FontSize', 30, 'HorizontalAlignment', 'Left')

set(gca, 'FontSize', 20)
disp('Lillietest results for figure ALLXERROR: ')
[h,p]  = lillietest(allXErrorsTCSValid)
